pub struct NodeKey(/* private fields */);Trait Implementations
Sourceimpl Key for NodeKey
impl Key for NodeKey
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for NodeKey
impl Ord for NodeKey
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for NodeKey
impl PartialOrd for NodeKey
impl Copy for NodeKey
impl Eq for NodeKey
impl StructuralPartialEq for NodeKey